@@ -1,54 +1,59 @@
+{-# OPTIONS_GHC -w #-}
 {-# OPTIONS -fglasgow-exts -cpp #-}
+{-# OPTIONS_GHC -w #-}
 module AttrGrammarParser (agParser) where
 import ParseMonad
 import AttrGrammar
-import Array
-#if __GLASGOW_HASKELL__ >= 503
-import GHC.Exts
+import qualified Data.Array as Happy_Data_Array
+import qualified GHC.Exts as Happy_GHC_Exts
+import Control.Applicative(Applicative(..))
+
+-- parser produced by Happy Version 1.19.4
+
+newtype HappyAbsSyn  = HappyAbsSyn HappyAny
+#if __GLASGOW_HASKELL__ >= 607
+type HappyAny = Happy_GHC_Exts.Any
 #else
-import GlaExts
+type HappyAny = forall a . a
 #endif
-
--- parser produced by Happy Version 1.15
-
-newtype HappyAbsSyn  = HappyAbsSyn (() -> ())
 happyIn4 :: ([AgRule]) -> (HappyAbsSyn )
-happyIn4 x = unsafeCoerce# x
+happyIn4 x = Happy_GHC_Exts.unsafeCoerce# x
 {-# INLINE happyIn4 #-}
 happyOut4 :: (HappyAbsSyn ) -> ([AgRule])
-happyOut4 x = unsafeCoerce# x
+happyOut4 x = Happy_GHC_Exts.unsafeCoerce# x
 {-# INLINE happyOut4 #-}
 happyIn5 :: ([AgRule]) -> (HappyAbsSyn )
-happyIn5 x = unsafeCoerce# x
+happyIn5 x = Happy_GHC_Exts.unsafeCoerce# x
 {-# INLINE happyIn5 #-}
 happyOut5 :: (HappyAbsSyn ) -> ([AgRule])
-happyOut5 x = unsafeCoerce# x
+happyOut5 x = Happy_GHC_Exts.unsafeCoerce# x
 {-# INLINE happyOut5 #-}
 happyIn6 :: (AgRule) -> (HappyAbsSyn )
-happyIn6 x = unsafeCoerce# x
+happyIn6 x = Happy_GHC_Exts.unsafeCoerce# x
 {-# INLINE happyIn6 #-}
 happyOut6 :: (HappyAbsSyn ) -> (AgRule)
-happyOut6 x = unsafeCoerce# x
+happyOut6 x = Happy_GHC_Exts.unsafeCoerce# x
 {-# INLINE happyOut6 #-}
 happyIn7 :: ([AgToken]) -> (HappyAbsSyn )
-happyIn7 x = unsafeCoerce# x
+happyIn7 x = Happy_GHC_Exts.unsafeCoerce# x
 {-# INLINE happyIn7 #-}
 happyOut7 :: (HappyAbsSyn ) -> ([AgToken])
-happyOut7 x = unsafeCoerce# x
+happyOut7 x = Happy_GHC_Exts.unsafeCoerce# x
 {-# INLINE happyOut7 #-}
 happyIn8 :: ([AgToken]) -> (HappyAbsSyn )
-happyIn8 x = unsafeCoerce# x
+happyIn8 x = Happy_GHC_Exts.unsafeCoerce# x
 {-# INLINE happyIn8 #-}
 happyOut8 :: (HappyAbsSyn ) -> ([AgToken])
-happyOut8 x = unsafeCoerce# x
+happyOut8 x = Happy_GHC_Exts.unsafeCoerce# x
 {-# INLINE happyOut8 #-}
-happyInTok :: AgToken -> (HappyAbsSyn )
-happyInTok x = unsafeCoerce# x
+happyInTok :: (AgToken) -> (HappyAbsSyn )
+happyInTok x = Happy_GHC_Exts.unsafeCoerce# x
 {-# INLINE happyInTok #-}
-happyOutTok :: (HappyAbsSyn ) -> AgToken
-happyOutTok x = unsafeCoerce# x
+happyOutTok :: (HappyAbsSyn ) -> (AgToken)
+happyOutTok x = Happy_GHC_Exts.unsafeCoerce# x
 {-# INLINE happyOutTok #-}
 
+
 happyActOffsets :: HappyAddr
 happyActOffsets = HappyA# "\x0f\x00\x0f\x00\x00\x00\x30\x00\x0a\x00\x2e\x00\x2d\x00\x2b\x00\x14\x00\x0a\x00\x0a\x00\x0a\x00\x00\x00\x01\x00\x0a\x00\x0a\x00\x0a\x00\x0a\x00\x0a\x00\x0f\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x2c\x00\x01\x00\x01\x00\x01\x00\x01\x00\x01\x00\x0a\x00\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x26\x00\x0a\x00\x00\x00\x01\x00\x00\x00\x00\x00"#
 
@@ -64,7 +69,7 @@ happyCheck = HappyA# "\xff\xff\x04\x00\x01\x00\x04\x00\x03\x00\x04\x00\x03\x00\x
 happyTable :: HappyAddr
 happyTable = HappyA# "\x00\x00\x2f\x00\x1c\x00\x25\x00\x1d\x00\x1e\x00\x2d\x00\x1f\x00\x20\x00\x21\x00\x22\x00\x0e\x00\x14\x00\x03\x00\x0f\x00\x26\x00\x10\x00\x11\x00\x12\x00\x13\x00\x05\x00\x06\x00\x07\x00\x08\x00\x08\x00\x02\x00\x03\x00\x02\x00\x03\x00\x27\x00\xff\xff\x28\x00\x29\x00\x2a\x00\x2b\x00\x15\x00\x16\x00\x17\x00\x18\x00\x19\x00\x2f\x00\x1a\x00\x22\x00\x23\x00\x24\x00\x0c\x00\x2d\x00\x0a\x00\x00\x00\x0b\x00\x0c\x00\x14\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"#
 
-happyReduceArr = array (1, 23) [
+happyReduceArr = Happy_Data_Array.array (1, 23) [
 	(1 , happyReduce_1),
 	(2 , happyReduce_2),
 	(3 , happyReduce_3),
@@ -93,14 +98,14 @@ happyReduceArr = array (1, 23) [
 happy_n_terms = 11 :: Int
 happy_n_nonterms = 5 :: Int
 
-happyReduce_1 = happySpecReduce_1 0# happyReduction_1
+happyReduce_1 = happySpecReduce_1  0# happyReduction_1
 happyReduction_1 happy_x_1
 	 =  case happyOut5 happy_x_1 of { happy_var_1 -> 
 	happyIn4
 		 (happy_var_1
 	)}
 
-happyReduce_2 = happySpecReduce_3 1# happyReduction_2
+happyReduce_2 = happySpecReduce_3  1# happyReduction_2
 happyReduction_2 happy_x_3
 	happy_x_2
 	happy_x_1
@@ -110,19 +115,19 @@ happyReduction_2 happy_x_3
 		 (happy_var_1 : happy_var_3
 	)}}
 
-happyReduce_3 = happySpecReduce_1 1# happyReduction_3
+happyReduce_3 = happySpecReduce_1  1# happyReduction_3
 happyReduction_3 happy_x_1
 	 =  case happyOut6 happy_x_1 of { happy_var_1 -> 
 	happyIn5
 		 (happy_var_1 : []
 	)}
 
-happyReduce_4 = happySpecReduce_0 1# happyReduction_4
+happyReduce_4 = happySpecReduce_0  1# happyReduction_4
 happyReduction_4  =  happyIn5
 		 ([]
 	)
 
-happyReduce_5 = happySpecReduce_3 2# happyReduction_5
+happyReduce_5 = happySpecReduce_3  2# happyReduction_5
 happyReduction_5 happy_x_3
 	happy_x_2
 	happy_x_1
@@ -132,7 +137,7 @@ happyReduction_5 happy_x_3
 		 (SelfAssign (selfRefVal happy_var_1) happy_var_3
 	)}}
 
-happyReduce_6 = happySpecReduce_3 2# happyReduction_6
+happyReduce_6 = happySpecReduce_3  2# happyReduction_6
 happyReduction_6 happy_x_3
 	happy_x_2
 	happy_x_1
@@ -142,7 +147,7 @@ happyReduction_6 happy_x_3
 		 (SubAssign (subRefVal happy_var_1) happy_var_3
 	)}}
 
-happyReduce_7 = happySpecReduce_3 2# happyReduction_7
+happyReduce_7 = happySpecReduce_3  2# happyReduction_7
 happyReduction_7 happy_x_3
 	happy_x_2
 	happy_x_1
@@ -152,7 +157,7 @@ happyReduction_7 happy_x_3
 		 (RightmostAssign (rightRefVal happy_var_1) happy_var_3
 	)}}
 
-happyReduce_8 = happySpecReduce_2 2# happyReduction_8
+happyReduce_8 = happySpecReduce_2  2# happyReduction_8
 happyReduction_8 happy_x_2
 	happy_x_1
 	 =  case happyOut7 happy_x_2 of { happy_var_2 -> 
@@ -174,7 +179,7 @@ happyReduction_9 (happy_x_4 `HappyStk`
 		 ([happy_var_1] ++ happy_var_2 ++ [happy_var_3] ++ happy_var_4
 	) `HappyStk` happyRest}}}}
 
-happyReduce_10 = happySpecReduce_2 3# happyReduction_10
+happyReduce_10 = happySpecReduce_2  3# happyReduction_10
 happyReduction_10 happy_x_2
 	happy_x_1
 	 =  case happyOutTok happy_x_1 of { happy_var_1 -> 
@@ -183,7 +188,7 @@ happyReduction_10 happy_x_2
 		 (happy_var_1 : happy_var_2
 	)}}
 
-happyReduce_11 = happySpecReduce_2 3# happyReduction_11
+happyReduce_11 = happySpecReduce_2  3# happyReduction_11
 happyReduction_11 happy_x_2
 	happy_x_1
 	 =  case happyOutTok happy_x_1 of { happy_var_1 -> 
@@ -192,7 +197,7 @@ happyReduction_11 happy_x_2
 		 (happy_var_1 : happy_var_2
 	)}}
 
-happyReduce_12 = happySpecReduce_2 3# happyReduction_12
+happyReduce_12 = happySpecReduce_2  3# happyReduction_12
 happyReduction_12 happy_x_2
 	happy_x_1
 	 =  case happyOutTok happy_x_1 of { happy_var_1 -> 
@@ -201,7 +206,7 @@ happyReduction_12 happy_x_2
 		 (happy_var_1 : happy_var_2
 	)}}
 
-happyReduce_13 = happySpecReduce_2 3# happyReduction_13
+happyReduce_13 = happySpecReduce_2  3# happyReduction_13
 happyReduction_13 happy_x_2
 	happy_x_1
 	 =  case happyOutTok happy_x_1 of { happy_var_1 -> 
@@ -210,7 +215,7 @@ happyReduction_13 happy_x_2
 		 (happy_var_1 : happy_var_2
 	)}}
 
-happyReduce_14 = happySpecReduce_2 3# happyReduction_14
+happyReduce_14 = happySpecReduce_2  3# happyReduction_14
 happyReduction_14 happy_x_2
 	happy_x_1
 	 =  case happyOutTok happy_x_1 of { happy_var_1 -> 
@@ -219,7 +224,7 @@ happyReduction_14 happy_x_2
 		 (happy_var_1 : happy_var_2
 	)}}
 
-happyReduce_15 = happySpecReduce_0 3# happyReduction_15
+happyReduce_15 = happySpecReduce_0  3# happyReduction_15
 happyReduction_15  =  happyIn7
 		 ([]
 	)
@@ -238,7 +243,7 @@ happyReduction_16 (happy_x_4 `HappyStk`
 		 ([happy_var_1] ++ happy_var_2 ++ [happy_var_3] ++ happy_var_4
 	) `HappyStk` happyRest}}}}
 
-happyReduce_17 = happySpecReduce_2 4# happyReduction_17
+happyReduce_17 = happySpecReduce_2  4# happyReduction_17
 happyReduction_17 happy_x_2
 	happy_x_1
 	 =  case happyOutTok happy_x_1 of { happy_var_1 -> 
@@ -247,7 +252,7 @@ happyReduction_17 happy_x_2
 		 (happy_var_1 : happy_var_2
 	)}}
 
-happyReduce_18 = happySpecReduce_2 4# happyReduction_18
+happyReduce_18 = happySpecReduce_2  4# happyReduction_18
 happyReduction_18 happy_x_2
 	happy_x_1
 	 =  case happyOutTok happy_x_1 of { happy_var_1 -> 
@@ -256,7 +261,7 @@ happyReduction_18 happy_x_2
 		 (happy_var_1 : happy_var_2
 	)}}
 
-happyReduce_19 = happySpecReduce_2 4# happyReduction_19
+happyReduce_19 = happySpecReduce_2  4# happyReduction_19
 happyReduction_19 happy_x_2
 	happy_x_1
 	 =  case happyOutTok happy_x_1 of { happy_var_1 -> 
@@ -265,7 +270,7 @@ happyReduction_19 happy_x_2
 		 (happy_var_1 : happy_var_2
 	)}}
 
-happyReduce_20 = happySpecReduce_2 4# happyReduction_20
+happyReduce_20 = happySpecReduce_2  4# happyReduction_20
 happyReduction_20 happy_x_2
 	happy_x_1
 	 =  case happyOutTok happy_x_1 of { happy_var_1 -> 
@@ -274,7 +279,7 @@ happyReduction_20 happy_x_2
 		 (happy_var_1 : happy_var_2
 	)}}
 
-happyReduce_21 = happySpecReduce_2 4# happyReduction_21
+happyReduce_21 = happySpecReduce_2  4# happyReduction_21
 happyReduction_21 happy_x_2
 	happy_x_1
 	 =  case happyOutTok happy_x_1 of { happy_var_1 -> 
@@ -283,7 +288,7 @@ happyReduction_21 happy_x_2
 		 (happy_var_1 : happy_var_2
 	)}}
 
-happyReduce_22 = happySpecReduce_2 4# happyReduction_22
+happyReduce_22 = happySpecReduce_2  4# happyReduction_22
 happyReduction_22 happy_x_2
 	happy_x_1
 	 =  case happyOutTok happy_x_1 of { happy_var_1 -> 
@@ -292,7 +297,7 @@ happyReduction_22 happy_x_2
 		 (happy_var_1 : happy_var_2
 	)}}
 
-happyReduce_23 = happySpecReduce_0 4# happyReduction_23
+happyReduce_23 = happySpecReduce_0  4# happyReduction_23
 happyReduction_23  =  happyIn8
 		 ([]
 	)
@@ -301,7 +306,7 @@ happyNewToken action sts stk
 	= agLexer(\tk -> 
 	let cont i = happyDoAction i tk action sts stk in
 	case tk of {
-	AgTok_EOF -> happyDoAction 10# (error "reading EOF!") action sts stk;
+	AgTok_EOF -> happyDoAction 10# tk action sts stk;
 	AgTok_LBrace -> cont 1#;
 	AgTok_RBrace -> cont 2#;
 	AgTok_Semicolon -> cont 3#;
@@ -311,10 +316,11 @@ happyNewToken action sts stk
 	AgTok_SubRef _ -> cont 7#;
 	AgTok_RightmostRef _ -> cont 8#;
 	AgTok_Unknown _ -> cont 9#;
-	_ -> happyError'
+	_ -> happyError' tk
 	})
 
-happyError_ tk = happyError'
+happyError_ 10# tk = happyError' tk
+happyError_ _ tk = happyError' tk
 
 happyThen :: () => P a -> (a -> P b) -> P b
 happyThen = (>>=)
@@ -323,36 +329,54 @@ happyReturn = (return)
 happyThen1 = happyThen
 happyReturn1 :: () => a -> P a
 happyReturn1 = happyReturn
-happyError' :: () => P a
-happyError' = happyError
+happyError' :: () => (AgToken) -> P a
+happyError' tk = (\token -> happyError) tk
 
 agParser = happySomeParser where
   happySomeParser = happyThen (happyParse 0#) (\x -> happyReturn (happyOut4 x))
 
 happySeq = happyDontSeq
 
+
 happyError :: P a
 happyError = fail ("Parse error\n")
-{-# LINE 1 "GenericTemplate.hs" #-}
+{-# LINE 1 "templates/GenericTemplate.hs" #-}
+{-# LINE 1 "templates/GenericTemplate.hs" #-}
 {-# LINE 1 "<built-in>" #-}
-{-# LINE 1 "<command line>" #-}
-{-# LINE 1 "GenericTemplate.hs" #-}
--- $Id$
+{-# LINE 1 "<command-line>" #-}
+{-# LINE 1 "templates/GenericTemplate.hs" #-}
+-- Id: GenericTemplate.hs,v 1.26 2005/01/14 14:47:22 simonmar Exp 
 
-{-# LINE 28 "GenericTemplate.hs" #-}
-
-
-data Happy_IntList = HappyCons Int# Happy_IntList
+{-# LINE 13 "templates/GenericTemplate.hs" #-}
 
 
 
 
 
-{-# LINE 49 "GenericTemplate.hs" #-}
+-- Do not remove this comment. Required to fix CPP parsing when using GCC and a clang-compiled alex.
+#if __GLASGOW_HASKELL__ > 706
+#define LT(n,m) ((Happy_GHC_Exts.tagToEnum# (n Happy_GHC_Exts.<# m)) :: Bool)
+#define GTE(n,m) ((Happy_GHC_Exts.tagToEnum# (n Happy_GHC_Exts.>=# m)) :: Bool)
+#define EQ(n,m) ((Happy_GHC_Exts.tagToEnum# (n Happy_GHC_Exts.==# m)) :: Bool)
+#else
+#define LT(n,m) (n Happy_GHC_Exts.<# m)
+#define GTE(n,m) (n Happy_GHC_Exts.>=# m)
+#define EQ(n,m) (n Happy_GHC_Exts.==# m)
+#endif
+{-# LINE 46 "templates/GenericTemplate.hs" #-}
 
-{-# LINE 59 "GenericTemplate.hs" #-}
 
-{-# LINE 68 "GenericTemplate.hs" #-}
+data Happy_IntList = HappyCons Happy_GHC_Exts.Int# Happy_IntList
+
+
+
+
+
+{-# LINE 67 "templates/GenericTemplate.hs" #-}
+
+{-# LINE 77 "templates/GenericTemplate.hs" #-}
+
+{-# LINE 86 "templates/GenericTemplate.hs" #-}
 
 infixr 9 `HappyStk`
 data HappyStk a = HappyStk a (HappyStk a)
@@ -369,9 +393,9 @@ happyParse start_state = happyNewToken start_state notHappyAtAll notHappyAtAll
 -- parse (a %partial parser).  We must ignore the saved token on the top of
 -- the stack in this case.
 happyAccept 0# tk st sts (_ `HappyStk` ans `HappyStk` _) =
-	happyReturn1 ans
+        happyReturn1 ans
 happyAccept j tk st sts (HappyStk ans _) = 
-	(happyTcHack j (happyTcHack st)) (happyReturn1 ans)
+        (happyTcHack j (happyTcHack st)) (happyReturn1 ans)
 
 -----------------------------------------------------------------------------
 -- Arrays only: do the next action
@@ -379,57 +403,46 @@ happyAccept j tk st sts (HappyStk ans _) =
 
 
 happyDoAction i tk st
-	= {- nothing -}
+        = {- nothing -}
 
 
-	  case action of
-		0#		  -> {- nothing -}
-				     happyFail i tk st
-		-1# 	  -> {- nothing -}
-				     happyAccept i tk st
-		n | (n <# (0# :: Int#)) -> {- nothing -}
+          case action of
+                0#           -> {- nothing -}
+                                     happyFail i tk st
+                -1#          -> {- nothing -}
+                                     happyAccept i tk st
+                n | LT(n,(0# :: Happy_GHC_Exts.Int#)) -> {- nothing -}
 
-				     (happyReduceArr ! rule) i tk st
-				     where rule = (I# ((negateInt# ((n +# (1# :: Int#))))))
-		n		  -> {- nothing -}
+                                                   (happyReduceArr Happy_Data_Array.! rule) i tk st
+                                                   where rule = (Happy_GHC_Exts.I# ((Happy_GHC_Exts.negateInt# ((n Happy_GHC_Exts.+# (1# :: Happy_GHC_Exts.Int#))))))
+                n                 -> {- nothing -}
 
 
-				     happyShift new_state i tk st
-				     where new_state = (n -# (1# :: Int#))
+                                     happyShift new_state i tk st
+                                     where new_state = (n Happy_GHC_Exts.-# (1# :: Happy_GHC_Exts.Int#))
    where off    = indexShortOffAddr happyActOffsets st
-	 off_i  = (off +# i)
-	 check  = if (off_i >=# (0# :: Int#))
-			then (indexShortOffAddr happyCheck off_i ==#  i)
-			else False
- 	 action | check     = indexShortOffAddr happyTable off_i
-		| otherwise = indexShortOffAddr happyDefActions st
-
-{-# LINE 127 "GenericTemplate.hs" #-}
+         off_i  = (off Happy_GHC_Exts.+# i)
+         check  = if GTE(off_i,(0# :: Happy_GHC_Exts.Int#))
+                  then EQ(indexShortOffAddr happyCheck off_i, i)
+                  else False
+         action
+          | check     = indexShortOffAddr happyTable off_i
+          | otherwise = indexShortOffAddr happyDefActions st
 
 
 indexShortOffAddr (HappyA# arr) off =
-#if __GLASGOW_HASKELL__ > 500
-	narrow16Int# i
-#elif __GLASGOW_HASKELL__ == 500
-	intToInt16# i
-#else
-	(i `iShiftL#` 16#) `iShiftRA#` 16#
-#endif
+        Happy_GHC_Exts.narrow16Int# i
   where
-#if __GLASGOW_HASKELL__ >= 503
-	i = word2Int# ((high `uncheckedShiftL#` 8#) `or#` low)
-#else
-	i = word2Int# ((high `shiftL#` 8#) `or#` low)
-#endif
-	high = int2Word# (ord# (indexCharOffAddr# arr (off' +# 1#)))
-	low  = int2Word# (ord# (indexCharOffAddr# arr off'))
-	off' = off *# 2#
+        i = Happy_GHC_Exts.word2Int# (Happy_GHC_Exts.or# (Happy_GHC_Exts.uncheckedShiftL# high 8#) low)
+        high = Happy_GHC_Exts.int2Word# (Happy_GHC_Exts.ord# (Happy_GHC_Exts.indexCharOffAddr# arr (off' Happy_GHC_Exts.+# 1#)))
+        low  = Happy_GHC_Exts.int2Word# (Happy_GHC_Exts.ord# (Happy_GHC_Exts.indexCharOffAddr# arr off'))
+        off' = off Happy_GHC_Exts.*# 2#
 
 
 
 
 
-data HappyAddr = HappyA# Addr#
+data HappyAddr = HappyA# Happy_GHC_Exts.Addr#
 
 
 
@@ -437,13 +450,13 @@ data HappyAddr = HappyA# Addr#
 -----------------------------------------------------------------------------
 -- HappyState data type (not arrays)
 
-{-# LINE 170 "GenericTemplate.hs" #-}
+{-# LINE 170 "templates/GenericTemplate.hs" #-}
 
 -----------------------------------------------------------------------------
 -- Shifting a token
 
 happyShift new_state 0# tk st sts stk@(x `HappyStk` _) =
-     let i = (case unsafeCoerce# x of { (I# (i)) -> i }) in
+     let i = (case Happy_GHC_Exts.unsafeCoerce# x of { (Happy_GHC_Exts.I# (i)) -> i }) in
 --     trace "shifting the error token" $
      happyDoAction i tk new_state (HappyCons (st) (sts)) (stk)
 
@@ -478,23 +491,40 @@ happySpecReduce_3 nt fn j tk _ (HappyCons (_) ((HappyCons (_) (sts@((HappyCons (
 happyReduce k i fn 0# tk st sts stk
      = happyFail 0# tk st sts stk
 happyReduce k nt fn j tk st sts stk
-     = case happyDrop (k -# (1# :: Int#)) sts of
-	 sts1@((HappyCons (st1@(action)) (_))) ->
-        	let r = fn stk in  -- it doesn't hurt to always seq here...
-       		happyDoSeq r (happyGoto nt j tk st1 sts1 r)
+     = case happyDrop (k Happy_GHC_Exts.-# (1# :: Happy_GHC_Exts.Int#)) sts of
+         sts1@((HappyCons (st1@(action)) (_))) ->
+                let r = fn stk in  -- it doesn't hurt to always seq here...
+                happyDoSeq r (happyGoto nt j tk st1 sts1 r)
 
 happyMonadReduce k nt fn 0# tk st sts stk
      = happyFail 0# tk st sts stk
 happyMonadReduce k nt fn j tk st sts stk =
-        happyThen1 (fn stk) (\r -> happyGoto nt j tk st1 sts1 (r `HappyStk` drop_stk))
-       where sts1@((HappyCons (st1@(action)) (_))) = happyDrop k (HappyCons (st) (sts))
-             drop_stk = happyDropStk k stk
+      case happyDrop k (HappyCons (st) (sts)) of
+        sts1@((HappyCons (st1@(action)) (_))) ->
+          let drop_stk = happyDropStk k stk in
+          happyThen1 (fn stk tk) (\r -> happyGoto nt j tk st1 sts1 (r `HappyStk` drop_stk))
+
+happyMonad2Reduce k nt fn 0# tk st sts stk
+     = happyFail 0# tk st sts stk
+happyMonad2Reduce k nt fn j tk st sts stk =
+      case happyDrop k (HappyCons (st) (sts)) of
+        sts1@((HappyCons (st1@(action)) (_))) ->
+         let drop_stk = happyDropStk k stk
+
+             off = indexShortOffAddr happyGotoOffsets st1
+             off_i = (off Happy_GHC_Exts.+# nt)
+             new_state = indexShortOffAddr happyTable off_i
+
+
+
+          in
+          happyThen1 (fn stk tk) (\r -> happyNewToken new_state sts1 (r `HappyStk` drop_stk))
 
 happyDrop 0# l = l
-happyDrop n (HappyCons (_) (t)) = happyDrop (n -# (1# :: Int#)) t
+happyDrop n (HappyCons (_) (t)) = happyDrop (n Happy_GHC_Exts.-# (1# :: Happy_GHC_Exts.Int#)) t
 
 happyDropStk 0# l = l
-happyDropStk n (x `HappyStk` xs) = happyDropStk (n -# (1#::Int#)) xs
+happyDropStk n (x `HappyStk` xs) = happyDropStk (n Happy_GHC_Exts.-# (1#::Happy_GHC_Exts.Int#)) xs
 
 -----------------------------------------------------------------------------
 -- Moving to a new state after a reduction
@@ -503,9 +533,9 @@ happyDropStk n (x `HappyStk` xs) = happyDropStk (n -# (1#::Int#)) xs
 happyGoto nt j tk st = 
    {- nothing -}
    happyDoAction j tk new_state
-   where off    = indexShortOffAddr happyGotoOffsets st
-	 off_i  = (off +# nt)
- 	 new_state = indexShortOffAddr happyTable off_i
+   where off = indexShortOffAddr happyGotoOffsets st
+         off_i = (off Happy_GHC_Exts.+# nt)
+         new_state = indexShortOffAddr happyTable off_i
 
 
 
@@ -514,9 +544,10 @@ happyGoto nt j tk st =
 -- Error recovery (0# is the error token)
 
 -- parse error if we are in recovery and we fail again
-happyFail  0# tk old_st _ stk =
---	trace "failing" $ 
-    	happyError_ tk
+happyFail 0# tk old_st _ stk@(x `HappyStk` _) =
+     let i = (case Happy_GHC_Exts.unsafeCoerce# x of { (Happy_GHC_Exts.I# (i)) -> i }) in
+--      trace "failing" $ 
+        happyError_ i tk
 
 {-  We don't need state discarding for our restricted implementation of
     "error".  In fact, it can cause some bogus parses, so I've disabled it
@@ -524,35 +555,36 @@ happyFail  0# tk old_st _ stk =
 
 -- discard a state
 happyFail  0# tk old_st (HappyCons ((action)) (sts)) 
-						(saved_tok `HappyStk` _ `HappyStk` stk) =
---	trace ("discarding state, depth " ++ show (length stk))  $
-	happyDoAction 0# tk action sts ((saved_tok`HappyStk`stk))
+                                                (saved_tok `HappyStk` _ `HappyStk` stk) =
+--      trace ("discarding state, depth " ++ show (length stk))  $
+        happyDoAction 0# tk action sts ((saved_tok`HappyStk`stk))
 -}
 
 -- Enter error recovery: generate an error token,
 --                       save the old token and carry on.
 happyFail  i tk (action) sts stk =
 --      trace "entering error recovery" $
-	happyDoAction 0# tk action sts ( (unsafeCoerce# (I# (i))) `HappyStk` stk)
+        happyDoAction 0# tk action sts ( (Happy_GHC_Exts.unsafeCoerce# (Happy_GHC_Exts.I# (i))) `HappyStk` stk)
 
 -- Internal happy errors:
 
+notHappyAtAll :: a
 notHappyAtAll = error "Internal Happy error\n"
 
 -----------------------------------------------------------------------------
 -- Hack to get the typechecker to accept our action functions
 
 
-happyTcHack :: Int# -> a -> a
+happyTcHack :: Happy_GHC_Exts.Int# -> a -> a
 happyTcHack x y = y
 {-# INLINE happyTcHack #-}
 
 
 -----------------------------------------------------------------------------
 -- Seq-ing.  If the --strict flag is given, then Happy emits 
---	happySeq = happyDoSeq
+--      happySeq = happyDoSeq
 -- otherwise it emits
--- 	happySeq = happyDontSeq
+--      happySeq = happyDontSeq
 
 happyDoSeq, happyDontSeq :: a -> b -> b
 happyDoSeq   a b = a `seq` b
